==> opensearch-dashboards-2.6.0.tgz: opensearch-dashboards/src/plugins/console/server/routes/api/console/proxy/validation_config.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.routeValidationConfig = void 0;

var _configSchema = require("@osd/config-schema");

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const acceptedHttpVerb = _configSchema.schema.string({
  validate: method => {
    return ['HEAD', 'GET', 'POST', 'PUT', 'DELETE'].some(verb => verb.toLowerCase() === method.toLowerCase()) ? undefined : `Method must be one of, case insensitive ['HEAD', 'GET', 'POST', 'PUT', 'DELETE']. Received '${method}'.`;
  }
});

const nonEmptyString = _configSchema.schema.string({
  validate: s => s === '' ? 'Expected non-empty string' : undefined
});

const routeValidationConfig = {
  query: _configSchema.schema.object({
    method: acceptedHttpVerb,
    path: nonEmptyString
  }),
  body: _configSchema.schema.stream()
};
exports.routeValidationConfig = routeValidationConfig;

==> opensearch-dashboards-2.10.0.tgz: opensearch-dashboards/src/plugins/console/server/routes/api/console/proxy/validation_config.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.routeValidationConfig = void 0;

var _configSchema = require("@osd/config-schema");

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const acceptedHttpVerb = _configSchema.schema.string({
  validate: method => {
    return ['HEAD', 'GET', 'POST', 'PUT', 'DELETE'].some(verb => verb.toLowerCase() === method.toLowerCase()) ? undefined : `Method must be one of, case insensitive ['HEAD', 'GET', 'POST', 'PUT', 'DELETE']. Received '${method}'.`;
  }
});

const nonEmptyString = _configSchema.schema.string({
  validate: s => s === '' ? 'Expected non-empty string' : undefined
});

const routeValidationConfig = {
  query: _configSchema.schema.object({
    method: acceptedHttpVerb,
    path: nonEmptyString,
    dataSourceId: _configSchema.schema.maybe(_configSchema.schema.string())
  }),
  body: _configSchema.schema.stream()
};
exports.routeValidationConfig = routeValidationConfig;
